==> rsyslog-8.38.0.tar.gz: rsyslog-8.38.0/tests/imfile-endregex-timeout-with-shutdown.sh <==
#!/bin/bash
# This is part of the rsyslog testbench, licensed under ASL 2.0
. $srcdir/diag.sh init
. $srcdir/diag.sh check-inotify-only
generate_conf
add_conf '
module(load="../plugins/imfile/.libs/imfile" timeoutGranularity="1")

input(type="imfile" File="./'$RSYSLOG_DYNNAME'.input" Tag="file:"
      PersistStateInterval="1" readTimeout="2" startmsg.regex="^[^ ]")

template(name="outfmt" type="list") {
  constant(value="HEADER ")
  property(name="msg" format="json")
  constant(value="\n")
}

if $msg contains "msgnum:" then
	action( type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
'
startup

# we need to sleep a bit between writes to give imfile a chance
# to pick up the data (IN MULTIPLE ITERATIONS!)
echo 'msgnum:0
 msgnum:1' > $RSYSLOG_DYNNAME.input
./msleep 8000
echo ' msgnum:2
 msgnum:3' >> $RSYSLOG_DYNNAME.input

# we now do a stop and restart of rsyslog. This checks that everything
# works across restarts.
shutdown_when_empty # shut down rsyslogd when done processing messages
wait_shutdown    # we need to wait until rsyslogd is finished!
startup

# new data
echo ' msgnum:4' >> $RSYSLOG_DYNNAME.input
./msleep 8000
echo ' msgnum:5
 msgnum:6' >> $RSYSLOG_DYNNAME.input
./msleep 8000

# the next line terminates our test. It is NOT written to the output file,
# as imfile waits whether or not there is a follow-up line that it needs
# to combine.
#echo 'END OF TEST' >> $RSYSLOG_DYNNAME.input
#./msleep 2000

shutdown_when_empty
wait_shutdown

EXPECTED='HEADER msgnum:0\\n msgnum:1
HEADER  msgnum:2\\n msgnum:3\\n msgnum:4
HEADER  msgnum:5\\n msgnum:6'
cmp_exact $RSYSLOG_OUT_LOG
exit_test

==> rsyslog-8.40.0.tar.gz: rsyslog-8.40.0/tests/imfile-endregex-timeout-with-shutdown.sh <==
#!/bin/bash
# This is part of the rsyslog testbench, licensed under ASL 2.0
. ${srcdir:=.}/diag.sh init
. $srcdir/diag.sh check-inotify-only
export IMFILECHECKTIMEOUT="30"

generate_conf
add_conf '
module(load="../plugins/imfile/.libs/imfile" timeoutGranularity="1")

input(type="imfile" File="./'$RSYSLOG_DYNNAME'.input" Tag="file:"
      PersistStateInterval="1" readTimeout="2" startmsg.regex="^[^ ]")

template(name="outfmt" type="list") {
  constant(value="HEADER ")
  property(name="msg" format="json")
  constant(value="\n")
}

if $msg contains "msgnum:" then
	action( type="omfile" file=`echo $RSYSLOG_OUT_LOG` template="outfmt")
'
startup

# we need to sleep a bit between writes to give imfile a chance
# to pick up the data (IN MULTIPLE ITERATIONS!)
echo 'msgnum:0
 msgnum:1' > $RSYSLOG_DYNNAME.input
content_check_with_count "msgnum:0
 msgnum:1" 1 $IMFILECHECKTIMEOUT
echo ' msgnum:2
 msgnum:3' >> $RSYSLOG_DYNNAME.input

# we now do a stop and restart of rsyslog. This checks that everything
# works across restarts.
shutdown_when_empty # shut down rsyslogd when done processing messages
wait_shutdown    # we need to wait until rsyslogd is finished!
startup

# new data
echo ' msgnum:4' >> $RSYSLOG_DYNNAME.input
content_check_with_count "msgnum:2
 msgnum:3
 msgnum:4" 1 $IMFILECHECKTIMEOUT

echo ' msgnum:5
 msgnum:6' >> $RSYSLOG_DYNNAME.input
content_check_with_count "msgnum:5
 msgnum:6" 1 $IMFILECHECKTIMEOUT


# the next line terminates our test. It is NOT written to the output file,
# as imfile waits whether or not there is a follow-up line that it needs
# to combine.
echo 'END OF TEST' >> $RSYSLOG_DYNNAME.input

shutdown_when_empty
wait_shutdown
exit_test
